@@ -4,6 +4,25 @@ from bson import ObjectId
 
 from ..MuviBase import MuviBase
 
+card_brand_map = {
+    # Credito
+    'visa': 1,
+    'diners': 8,
+    'tarshop': 23,
+    'naranja': 24,
+    'pagofacil': 25,
+    'rapipago': 26,
+    'argencard': 30,
+    'cencosud': 43,
+    'cabal': 63,
+    'amex': 65,
+    'master': 104,
+    # Debito
+    'debvisa': 31,
+    'debmaster': 105,
+    'maestro': 106,
+    'debcabal': 108
+}
 
 def _format_card(response):
     return {
@@ -19,6 +38,10 @@ def _format_card(response):
 
 
 def _format(response):
+    try:
+        response['payment_method_id'] = str(card_brand_map[response['payment_method_id']])
+    except:
+        pass
     return {
         'id': response['id'],
         'transaction_amount': response['transaction_amount'],
